@@ -4,7 +4,7 @@ from typing import Optional, Union, Dict
 import pandas as pd  # type: ignore
 try:
     from .data.dicts import PRODUCTS, BRANDS, SLASH_PRODUCTS, BRANDS_WITH_NUMBERS  # type: ignore
-except ImportError:
+except (ImportError, ModuleNotFoundError):
     from data.dicts import PRODUCTS, BRANDS, SLASH_PRODUCTS, BRANDS_WITH_NUMBERS  # type: ignore
 
 
